@@ -21,7 +21,7 @@ use base qw( Test::Builder::Module );
 use Carp qw( croak );
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -184,6 +184,15 @@ sub _load_lite_app
   }, $index++);
 }
 
+sub _generate_port
+{
+  require IO::Socket::INET;
+  IO::Socket::INET->new(
+    Listen => 5, 
+    LocalAddr => '127.0.0.1',
+  )->sockport;
+}
+
 sub create_cluster_ok
 {
   my $self = shift;
@@ -191,7 +200,7 @@ sub create_cluster_ok
   my $total = scalar @_;
   my @urls = map { 
     my $url = Mojo::URL->new("http://127.0.0.1");
-    $url->port($self->t->ua->ioloop->generate_port);
+    $url->port(_generate_port);
     $url } (0..$total);
 
   push @{ $self->{urls} }, @urls;
@@ -384,7 +393,7 @@ sub create_plugauth_lite_ok
   {
     my $ua = $self->{auth_ua} = $self->_add_ua;
     my $url = Mojo::URL->new("http://127.0.0.1");
-    $url->port($self->t->ua->ioloop->generate_port);
+    $url->port(_generate_port);
   
     eval {
       require PlugAuth::Lite;
@@ -491,7 +500,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
